%define debug_package %{nil}

Name:           ocaml-xhtml
Version:        20050620
Release:        %mkrel 20
Summary:        OCaml module for creating valid XHTML 1.1 documents
License:        GPL
Group:          Development/OCaml
URL:            http://theorie.physik.uni-wuerzburg.de/~ohl/xhtml/
Source0:        http://theorie.physik.uni-wuerzburg.de/~ohl/xhtml/xhtml-%{version}.tar.gz
Patch0:         examples-Makefile-installed.patch
BuildRequires:  ocaml-findlib

%description
XHTML is a OCaml module for creating valid XHTML 1.1 (and XHTML 1.0)
documents. The validity of the pages is guaranteed by the OCaml type system.
(NB: at the time of writing, forms support was not complete, only basic
forms are implemented. Image maps are also not implemented yet.)

XHTML can be used for creating static documents, but it is not the most
conventient way to key in text heavy documents. Instead, it should be most
useful for database frontends etc.

XHTML is not a general XML processor that parses a DTD and checks the
validity of a document with respect to this DTD. This lack in flexibility
is made up for by the ability to perform prove validity by static type
checking.

The implementation uses a XML module for generating well formed---but not
necessarily valid with respect to some DTD---XML documents. The elements
of type XML.elt and attributes of type XML.attrib are then hidden behind
polymorphic phantom types type 'a elt = XML.elt and type 'a attrib =
XML.attrib with 'a set to appropriate polymorphic variants.

This approach can be adopted easily to other XML document types: MathML and
MusicML come to mind.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%setup -q -c xhtml-%{version}
%patch0 -p0
sed -i -e 's/\t/        /g' \
    *.mli  examples/*.ml  experimental/*.{ml,mli}

%build
make
mkdir doc
make doc

if [ -f META ]; then exit 1; fi
cat > META <<EOF
version = "%{version}"
description = "OCaml module for creating valid XHTML 1.1 documents"
archive(byte) = "xhtml.cma"
archive(native) = "xhtml.cmxa"
EOF

%install
mkdir -p %{buildroot}/%{_libdir}/ocaml
ocamlfind install xhtml \
    -destdir %{buildroot}/%{_libdir}/ocaml \
    META *.{mli,cmi,cma,cmx,cmxa,a}

%files
%doc README COPYING ChangeLog
%dir %{_libdir}/ocaml/xhtml
%{_libdir}/ocaml/xhtml/META
%{_libdir}/ocaml/xhtml/*.cma
%{_libdir}/ocaml/xhtml/*.cmi

%files devel
%doc doc/
%doc examples/
%doc experimental/
%{_libdir}/ocaml/xhtml/*.a
%{_libdir}/ocaml/xhtml/*.cmxa
%{_libdir}/ocaml/xhtml/*.cmx
%{_libdir}/ocaml/xhtml/*.mli


%changelog
* Sun Jan 10 2021 pterjan <pterjan> 20050620-20.mga8
+ Revision: 1670486
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 20050620-19.mga8
+ Revision: 1551173
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 20050620-18.mga8
+ Revision: 1544478
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 tv <tv> 20050620-17.mga8
+ Revision: 1483070
- rebuild for ocaml-4.10

* Tue Oct 23 2018 tv <tv> 20050620-16.mga7
+ Revision: 1324015
- rebuild with ocaml-4.07.1

* Mon Oct 22 2018 pterjan <pterjan> 20050620-15.mga7
+ Revision: 1323683
- Rebuild for ocam 4.07

* Sun Sep 23 2018 umeabot <umeabot> 20050620-14.mga7
+ Revision: 1299947
- Mageia 7 Mass Rebuild

* Sun Nov 26 2017 tv <tv> 20050620-13.mga7
+ Revision: 1179784
- rebuild for new ocaml
- rebuild for new ocaml

* Thu Nov 24 2016 neoclust <neoclust> 20050620-11.mga6
+ Revision: 1069797
- Rebuild against fixed ocaml

* Fri Feb 12 2016 umeabot <umeabot> 20050620-10.mga6
+ Revision: 956493
- Mageia 6 Mass Rebuild

* Wed Oct 21 2015 tv <tv> 20050620-9.mga6
+ Revision: 893227
- disable debuginfo

* Wed Oct 15 2014 umeabot <umeabot> 20050620-8.mga5
+ Revision: 743111
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 20050620-7.mga5
+ Revision: 683129
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 20050620-6.mga4
+ Revision: 508548
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 20050620-5.mga3
+ Revision: 361704
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 01 2012 blue_prawn <blue_prawn> 20050620-4.mga3
+ Revision: 301102
- rebuild for ocaml-4.00.0

* Sun Sep 30 2012 blue_prawn <blue_prawn> 20050620-3.mga3
+ Revision: 300835
- new rpm group for ocaml

* Wed Apr 18 2012 blue_prawn <blue_prawn> 20050620-2.mga2
+ Revision: 231391
- patch the example's Makefile for the installed lib

* Wed Apr 18 2012 blue_prawn <blue_prawn> 20050620-1.mga2
+ Revision: 231383
- imported package ocaml-xhtml

